==> aws-cdk-lib-2.0.0-rc.20-sources.jar: software/amazon/awscdk/services/sagemaker/CfnCodeRepositoryProps.java <==
package software.amazon.awscdk.services.sagemaker;

/**
 * Properties for defining a `AWS::SageMaker::CodeRepository`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-09-01T10:26:49.555Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_sagemaker.CfnCodeRepositoryProps")
@software.amazon.jsii.Jsii.Proxy(CfnCodeRepositoryProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnCodeRepositoryProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::SageMaker::CodeRepository.GitConfig`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getGitConfig();

    /**
     * `AWS::SageMaker::CodeRepository.CodeRepositoryName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCodeRepositoryName() {
        return null;
    }

    /**
     * `AWS::SageMaker::CodeRepository.Tags`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnCodeRepositoryProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnCodeRepositoryProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnCodeRepositoryProps> {
        private java.lang.Object gitConfig;
        private java.lang.String codeRepositoryName;
        private java.util.List<software.amazon.awscdk.CfnTag> tags;

        /**
         * Sets the value of {@link CfnCodeRepositoryProps#getGitConfig}
         * @param gitConfig `AWS::SageMaker::CodeRepository.GitConfig`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder gitConfig(software.amazon.awscdk.services.sagemaker.CfnCodeRepository.GitConfigProperty gitConfig) {
            this.gitConfig = gitConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeRepositoryProps#getGitConfig}
         * @param gitConfig `AWS::SageMaker::CodeRepository.GitConfig`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder gitConfig(software.amazon.awscdk.IResolvable gitConfig) {
            this.gitConfig = gitConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeRepositoryProps#getCodeRepositoryName}
         * @param codeRepositoryName `AWS::SageMaker::CodeRepository.CodeRepositoryName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder codeRepositoryName(java.lang.String codeRepositoryName) {
            this.codeRepositoryName = codeRepositoryName;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeRepositoryProps#getTags}
         * @param tags `AWS::SageMaker::CodeRepository.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnCodeRepositoryProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnCodeRepositoryProps build() {
            return new Jsii$Proxy(gitConfig, codeRepositoryName, tags);
        }
    }

    /**
     * An implementation for {@link CfnCodeRepositoryProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnCodeRepositoryProps {
        private final java.lang.Object gitConfig;
        private final java.lang.String codeRepositoryName;
        private final java.util.List<software.amazon.awscdk.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.gitConfig = software.amazon.jsii.Kernel.get(this, "gitConfig", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.codeRepositoryName = software.amazon.jsii.Kernel.get(this, "codeRepositoryName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.lang.Object gitConfig, final java.lang.String codeRepositoryName, final java.util.List<? extends software.amazon.awscdk.CfnTag> tags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.gitConfig = java.util.Objects.requireNonNull(gitConfig, "gitConfig is required");
            this.codeRepositoryName = codeRepositoryName;
            this.tags = (java.util.List<software.amazon.awscdk.CfnTag>)tags;
        }

        @Override
        public final java.lang.Object getGitConfig() {
            return this.gitConfig;
        }

        @Override
        public final java.lang.String getCodeRepositoryName() {
            return this.codeRepositoryName;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("gitConfig", om.valueToTree(this.getGitConfig()));
            if (this.getCodeRepositoryName() != null) {
                data.set("codeRepositoryName", om.valueToTree(this.getCodeRepositoryName()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_sagemaker.CfnCodeRepositoryProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnCodeRepositoryProps.Jsii$Proxy that = (CfnCodeRepositoryProps.Jsii$Proxy) o;

            if (!gitConfig.equals(that.gitConfig)) return false;
            if (this.codeRepositoryName != null ? !this.codeRepositoryName.equals(that.codeRepositoryName) : that.codeRepositoryName != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.gitConfig.hashCode();
            result = 31 * result + (this.codeRepositoryName != null ? this.codeRepositoryName.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/sagemaker/CfnCodeRepositoryProps.java <==
package software.amazon.awscdk.services.sagemaker;

/**
 * Properties for defining a `CfnCodeRepository`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.sagemaker.*;
 * CfnCodeRepositoryProps cfnCodeRepositoryProps = CfnCodeRepositoryProps.builder()
 *         .gitConfig(GitConfigProperty.builder()
 *                 .repositoryUrl("repositoryUrl")
 *                 // the properties below are optional
 *                 .branch("branch")
 *                 .secretArn("secretArn")
 *                 .build())
 *         // the properties below are optional
 *         .codeRepositoryName("codeRepositoryName")
 *         .tags(List.of(CfnTag.builder()
 *                 .key("key")
 *                 .value("value")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:12.608Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_sagemaker.CfnCodeRepositoryProps")
@software.amazon.jsii.Jsii.Proxy(CfnCodeRepositoryProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnCodeRepositoryProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Configuration details for the Git repository, including the URL where it is located and the ARN of the AWS Secrets Manager secret that contains the credentials used to access the repository.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getGitConfig();

    /**
     * The name of the Git repository.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCodeRepositoryName() {
        return null;
    }

    /**
     * List of tags for Code Repository.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.CfnTag> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnCodeRepositoryProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnCodeRepositoryProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnCodeRepositoryProps> {
        java.lang.Object gitConfig;
        java.lang.String codeRepositoryName;
        java.util.List<software.amazon.awscdk.CfnTag> tags;

        /**
         * Sets the value of {@link CfnCodeRepositoryProps#getGitConfig}
         * @param gitConfig Configuration details for the Git repository, including the URL where it is located and the ARN of the AWS Secrets Manager secret that contains the credentials used to access the repository. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder gitConfig(software.amazon.awscdk.services.sagemaker.CfnCodeRepository.GitConfigProperty gitConfig) {
            this.gitConfig = gitConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeRepositoryProps#getGitConfig}
         * @param gitConfig Configuration details for the Git repository, including the URL where it is located and the ARN of the AWS Secrets Manager secret that contains the credentials used to access the repository. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder gitConfig(software.amazon.awscdk.IResolvable gitConfig) {
            this.gitConfig = gitConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeRepositoryProps#getCodeRepositoryName}
         * @param codeRepositoryName The name of the Git repository.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder codeRepositoryName(java.lang.String codeRepositoryName) {
            this.codeRepositoryName = codeRepositoryName;
            return this;
        }

        /**
         * Sets the value of {@link CfnCodeRepositoryProps#getTags}
         * @param tags List of tags for Code Repository.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.CfnTag> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.CfnTag>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnCodeRepositoryProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnCodeRepositoryProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnCodeRepositoryProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnCodeRepositoryProps {
        private final java.lang.Object gitConfig;
        private final java.lang.String codeRepositoryName;
        private final java.util.List<software.amazon.awscdk.CfnTag> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.gitConfig = software.amazon.jsii.Kernel.get(this, "gitConfig", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.codeRepositoryName = software.amazon.jsii.Kernel.get(this, "codeRepositoryName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.CfnTag.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.gitConfig = java.util.Objects.requireNonNull(builder.gitConfig, "gitConfig is required");
            this.codeRepositoryName = builder.codeRepositoryName;
            this.tags = (java.util.List<software.amazon.awscdk.CfnTag>)builder.tags;
        }

        @Override
        public final java.lang.Object getGitConfig() {
            return this.gitConfig;
        }

        @Override
        public final java.lang.String getCodeRepositoryName() {
            return this.codeRepositoryName;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.CfnTag> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("gitConfig", om.valueToTree(this.getGitConfig()));
            if (this.getCodeRepositoryName() != null) {
                data.set("codeRepositoryName", om.valueToTree(this.getCodeRepositoryName()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_sagemaker.CfnCodeRepositoryProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnCodeRepositoryProps.Jsii$Proxy that = (CfnCodeRepositoryProps.Jsii$Proxy) o;

            if (!gitConfig.equals(that.gitConfig)) return false;
            if (this.codeRepositoryName != null ? !this.codeRepositoryName.equals(that.codeRepositoryName) : that.codeRepositoryName != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.gitConfig.hashCode();
            result = 31 * result + (this.codeRepositoryName != null ? this.codeRepositoryName.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}
